### A Pluto.jl notebook ###
# v0.19.11

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ b72215bb-8e3a-46e2-8817-271befe1178c
begin
	using PlotlyBase
	using HypertextLiteral
	using PlutoUI
	using LinearAlgebra
	using NLsolve
end

# ╔═╡ 0b869e70-3717-11ec-202c-6b94dac7daf3
md"""
# Exemplo-Teste Final: Macroeconomia (L0236)

#### Duração: 1 hora e 30 minutos.

## Instituto Universitário de Lisboa (ISCTE--IUL)

**Junho 2022**
"""

# ╔═╡ b326715f-c37f-44d2-92f9-6264368a18b2
md"""
#### Nome: Inserir nome completo , Nº: 000001
"""

# ╔═╡ 694d78c7-4762-4d40-8f9a-6c3d16916d4e
begin
	function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsibity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
	end
end

# ╔═╡ 60bab761-8537-46e3-9940-953cd47da4be
md"""
#####  RESPONDA APENAS A 4 GRUPOS, de forma sucinta e objectiva
"""

# ╔═╡ 4109af60-6178-4148-8efe-890245077188
md"""
## Exercício 1 (5 pontos)
"""

# ╔═╡ 25743265-a4d8-45c0-8c17-e75a2858441a
md"""
**a)** Tomando em consideração a figura seguinte, pensa que a mesma suporta/rejeita empiricamente a Curva de Phillips? Justifique.
"""

# ╔═╡ e56d9748-1b72-48cf-ab1e-da84807da7c4
Resource("http://ebs.de.iscte.pt/aa_PC_FinalTest.png",:width=>700)

# ╔═╡ 15f5ca45-b1de-4203-ad0d-bdb45e1f9c10
md"""
**b)** O que é a Regra de Taylor?

**c)** O que é o défice primário orçamental?

**d)** Considere o modelo macroeconómico completo com as 4 equações fundamentais:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[2mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[2mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[2mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

----**d1.** No que consiste o equilíbrio macroeconómico?

----**d2.** Como é determinado o equilíbrio macroeconómico?

----**d3.** Como é que o Banco Central "fixa" o nível da taxa de juro nominal da economia?

**e)** O que é a zona chamada por "ZLB" e como é que a mesma é determinada?

"""

# ╔═╡ 4a5d4ce9-ce74-4dd5-8ef9-4abb333b1d4b
md"""
	!!! respostas
	    **a.** Resposta. 

		**b.** Resposta
  
		**c.** Resposta  

		**d1.** Resposta
		
		**d2.** Resposta
  
		**d3.** Resposta
	
		**e.** Resposta
  
	"""

# ╔═╡ c7e2c3fc-bf1c-4b1b-882a-b9e36d66a32b
# Não altere esta célula. Cotações por pergunta.
begin
	Ia = 0.0 * 1
	Ib = 0.0 * 1
	Ic = 0.0 * 1
	Id = 0.0 * 1
	Ie = 0.0 * 1
	I = Ia + Ib + Ic + Id +Ie
end

# ╔═╡ 9b0f3199-ff28-4820-bcad-e59bc65ce8a6
md"""
## Exercício 2 (5 pontos)
"""

# ╔═╡ 541d8125-e5d0-46ec-a26d-aa1a130c38b2
md"""
Considere as expressões da Lei de Okun e da Curva de Phillips, respectivamente:

$$\begin{aligned}
U-U_{n}=-0.5\left(Y-Y^{P}\right) \\[2mm]
\pi=\pi^{e}-0.6\left(U-U_{n}\right)+\rho \\
\end{aligned}$$

sabendo-se que, em termos de valores médios, $U_n=4\%$ e $\rho = 0\%$.

**a)** Como poderá obter a função AS?

**b)** Qual será o nível da taxa de desemprego que permitirá manter a taxa de inflação estável ao longo do tempo?

**c)** Suponha que o Governo, por razões políticas, tenta reduzir a taxa de desemprego para $3\%$. O que será expectável que aconteça à inflação nesta economia, caso $\{U_n, \rho\}$ permaneçam inalterados? Explique de forma sucinta.

**d)** Suponha que o Banco Central deseja reduzir a inflação, o que gera um aumento da taxa de desemprego para $5\%$. O que será expectável que aconteça à inflação nesta economia, caso $\{U_n, \rho\}$ permaneçam inalterados? Explique de forma sucinta.

**e)** Qual a variável macroeconómica que a figura seguinte permite calcular? Como é que esta é calculada?

"""

# ╔═╡ ae593638-a05c-4255-9681-39a9e10efd16
Resource("http://ebs.de.iscte.pt/aa_Unempl_FinalTest.png",:width=>800)

# ╔═╡ f604c97e-bbbf-42f3-b602-ae183a32acc7
md"""
	!!! respostas
	    **a.** Resposta

		**b.** Resposta
  
		**c.** Resposta  

		**d.** Resposta
	
		**e.** Resposta
  
	"""

# ╔═╡ cff3fc5b-326b-4efe-836b-229cd23f83cc
# Não altere esta célula. Cotações por pergunta.
begin
	IIa = 0.0 * 0.5
	IIb = 0.0 * 0.5
	IIc = 0.0 * 0.5
	IId = 0.0 * 0.5
	IIe = 0.0 * 2.0
	II = IIa + IIb + IIc + IId + IIe
end

# ╔═╡ 9b622087-ad34-4f19-9929-cbdf0256eae0
md"""
## Exercício 3 (5 pontos)
"""

# ╔═╡ 7a8ac6a0-09cf-437e-9b8d-277182c0cdd0
md"""
Considere o modelo macroeconómico completo com as 4 equações fundamentais:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[2mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[2mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[2mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

e é conhecida a seguinte informação:

$$\overline{A}=8.0 \ , \ m=2.0\ , \ \phi=0.2\ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma=2.8 \ , \ Y^{P}=14.8 \ ,  \ \rho=0$$

**a)** Calcule o nível de equílibrio para o PIB, a taxa de inflação, a taxa de juro real, e a taxa de juro nominal, usando um método à sua escolha (recomendamos o uso de `NLsolve`).

**b)** Suponha que o equilíbrio pode ser representado conforme figura "**An increase in public spending_3**". Se o Governo aumentar a despesa pública em 0.2 triliões de dólares, descreva os passos que a economia irá dar até chegar ao novo equilíbrio macroeconómico, indicando os *valores* do PIB e da taxa de inflação em cada um dos passos.

**c)** Usando a figura "**MP function_3**", quais serão os *valores* para a taxa de juro real, bem como à taxa de juro nominal, face ao ajustamento que resulta daquele aumento da despesa pública?

**d)** De acordo com a função MP acima apresentada, será possível existir um equilíbrio de longo prazo com uma taxa de inflação diferente da taxa de inflação-objectivo ($\pi^T$, ou "infation target") escolhida pelo Banco Central? Justifique de forma sucinta.


"""

# ╔═╡ 37e34e48-c2a7-4ffd-ac97-1a6ecb44ea92
begin	
	# Demand	
	Ā3 = 8.0
	λ3 = 0.5
	m3 = 2.0
	ϕ3 = 0.2
	r̄3 = 2.0	
	# Supply	
	γ3  = 2.8
	Yᴾ3 = 14.8
	πᵉ3 = 2.0
	ρ3  = 0.0	
	# Intercepts (useful to simplify notation)	
	πd_max3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3        # The AD curve y-axis' intercept
	πs_min3 = πᵉ3 - γ3 * Yᴾ3 + ρ3             # The AS curve y-axis' intercept
end;

# ╔═╡ d3341903-3381-47bf-b6b0-6b909542a032


# ╔═╡ c3ad91a0-45be-468b-8113-395e10902afb


# ╔═╡ f3d1f71c-5108-4394-a98d-dc670f1091ae
md"""
`ΔĀ3 = `$(@bind ΔĀ3 Slider(-1.0:0.05:1.0, default=0.0, show_value=true))
"""

# ╔═╡ 6db02201-bbe3-4ca8-a36b-7a5ac9e6385e
begin
	Y3 = 13.8:0.001:15.6
	
	πd3 = πd_max3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3) # AD function
	πs3 = πs_min3 .+ γ3 .*Y3             # AS function
	
	trace9_0 = scatter(; x = [14.8,14.8] , y = [-5,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	trace9_1 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y3, y = πs3, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [14.8], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))


	πd_max3_ΔĀ3 = ((Ā3 .+ ΔĀ3) ./ (λ3 .* ϕ3)) .- r̄3 ./ λ3 # New max value of the AD function
	
	πd3_ΔĀ3 = πd_max3_ΔĀ3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3) # AD function
	
	
	trace9_4 = scatter(; x = Y3, y = πd3_ΔĀ3, mode="lines" , line_color = "Magenta", 
					 line_width = "3", name  = "AD2")
		
	#trace9_5 = scatter(; x = [14.21], y = [2.947], text =["2"], 
	#				textposition = "top center", name ="Eq2", mode="markers+text", 
	#				marker_size= "12", marker_color="Magenta",
	#				textfont = attr(family="sans serif", size=16, color="black"))
	
	
	layout9_5 = Layout(;
					title_text ="An increase in public spending_3",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    #xaxis_range = [13.6, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.5 , 6])

   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3], layout9_5)
	
	
end

# ╔═╡ f4efa92e-9a43-4bc3-8924-9ef7adeba5fd
begin
	r3 = 0.0:0.01:5.0
	
	πmp3 = - (r̄3 ./ λ3) .+  r3 ./ λ3 
	
	trace4_1 = scatter(; x = r3, y = πmp3, mode="lines" , line_color = "Brown", line_width = "3",
			name  = "MP")
	
	trace4_2 = scatter(; x = [3.0], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	
	layout4_1 = Layout(;
					title_text = "MP Function_3",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [2.0, 4.5],
					xaxis_tickvals = [2, 2.5, 3, 3.5, 4, 4.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0 , 5])

   p4_1 = Plot([trace4_1, trace4_2], layout4_1)
end

# ╔═╡ b52852c9-8cd0-4070-bcd9-b73c63bb7b83
md"""
	!!! respostas
	    **a.** Resposta

		**b.** Resposta: passo 1
		
		**b.** Resposta: passo 2
	
		**c.** Resposta: passo 1
		
		**c.** Resposta: passo 2

		**d.** Resposta

	"""

# ╔═╡ 83da306c-64fa-4231-b396-b2006cd3ae05
# Não altere esta célula. Cotações por pergunta.
begin
	IIIa = 0.0 * 2
	IIIb = 0.0 * 1
	IIIc = 0.0 * 1
	IIId = 0.0 * 1
	III = IIIa + IIIb + IIIc + IIId 
end

# ╔═╡ 36a0155e-86a5-461a-9b29-bf5b12e29e1b
md"""
## Exercício 4 (5 pontos)
"""

# ╔═╡ 4f2bd28d-abe2-43eb-9b7c-65e4ee574499
md"""
Levando em consideração os mesmos dados do exercício anterior, ou seja:

$$\overline{A}=8.0 \ , \ m=2.0\ , \ \phi=0.2\ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma=2.8 \ , \ Y^{P}=14.8 \ ,  \ \rho=0$$

**a)** Calcule o nível da taxa de inflação que corresponde ao ZLB.

**b)** Suponha que existe um choque sobre a oferta, onde agora passamos a ter $\rho = -3.15$. O impacto deste choque pode ser visto na figura "**The AD/AS with a ZLB_4**". Será o ponto $1$ um ponto de equilíbrio de longo prazo? Justifique.

**c)** Qual será o novo ponto de equilíbrio de longo prazo?


**d)** Qual será o nível da taxa de juro nominal no ponto $2$? Justifique.

**e)** Suponha que devido a uma enorme descida nos preços do petróleo (e outras fontes energéticas), o choque na oferta seria muito maior do que na pergunta (b). O choque levaria a AS para o ponto $3$ (não para o ponto 1). Neste ponto, o que aconteceria à economia? Justifique de forma sucinta.


"""

# ╔═╡ bfd9b931-74b2-4f61-867c-cdba8df08d4e
md"""
	!!! respostas
	    **a.** Resposta

		**b.** Resposta
		
		**c.** Resposta
	
		**d.** Resposta
		
		**e.** Resposta
  
	"""

# ╔═╡ 1abf1b21-a268-45da-bcfc-b9cab7119ef4
# Não altere esta célula. Cotações por pergunta.
begin
	IVa = 0.0 * 1
	IVb = 0.0 * 1
	IVc = 0.0 * 1
	IVd = 0.0 * 1
	IVe = 0.0 * 1
	IV = IVa + IVb + IVc + IVd + IVe
end

# ╔═╡ 52c76dc2-146c-4178-9aa3-d132a0551168
md"""
## Exercício 5 (5 pontos)
"""

# ╔═╡ 40de1d39-effa-460b-8ccd-85d5be501a63
md"""

Levando em consideração os mesmos dados dos exercícios anteriores, ou seja:

$$\overline{A}=8.0 \ , \ m=2.0 \ , \ \phi=0.2 \ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma=2.8 \ , \ Y^{P}=14.8 \ ,  \ \rho=0$$

**a)** Calcule o nível do multiplicador fiscal, comparando-o em dois cenários distintos: (1) na zona do ZLB; (2) na zona normal (fora do ZLB).

**b)** Quais as razões que explicam que o multiplicador fiscal na zona da ZLB seja muito superior àquele que se verifica na zona normal.

**c)** A sustentabilidade da dívida pública é dada pela seguinte expressão:

$$d_{t}=p+\left(\frac{1+r}{1+g}\right) d_{t-1}$$

onde os símbolos representam as variáveis conforme slides. Usando os **sliders** abaixo (bem como a figura **"The evolution of Public Debt as % of GDP"**), partindo de uma situação inicial de $d=1$ (ou seja: Dívida Pública / PIB = 1) caracterize dois cenários diferentes: (1) o défice primário é $1\%$ do PIB $(p = 0.01)$; (2) o défice primário é $-1\%$ do PIB $(p =- 0.01)$.

**d)** Nas sociedades ocidentais, quais são os principais factores que mais têm contribuído para o crescimento da despesa pública nos últimos 60 anos? E para a quebra das receitas públicas? Quais serão os impactos destas forças sobre a sustentabilidade da dívida pública?
"""

# ╔═╡ 5ec7390c-2383-4033-9089-1c051b806912
md"""

`p = `$(@bind p Slider(-0.04:0.005:0.04, default=0.00, show_value=true))

`r = `$(@bind r Slider(0.0:0.0005:0.04, default=0.012, show_value=true))

`g = `$(@bind g Slider(0.0:0.0005:0.05, default=0.03, show_value=true))

`d_1 = `$(@bind d_1 Slider(0.0:0.25:2, default=1.00, show_value=true))

"""

# ╔═╡ f70f963d-1d2b-4db7-bf4c-4175ad1c3df8
md"""
	!!! respostas
	    **a.** Resposta

		**b.** Resposta
		
		**c.** Resposta
	
		**d.** Resposta
  
	"""

# ╔═╡ bc7a7a3d-b43a-4db1-9f42-212226e10a29
# Não altere esta célula. Cotações por pergunta.
begin
	Va = 0.0 * 1
	Vb = 0.0 * 1
	Vc = 0.0 * 1
	Vd = 0.0 * 2
	V = Va + Vb + Vc + Vd
end

# ╔═╡ f2956bed-9534-4c57-bfaa-fbef3c4af810
md"""
## Fim do teste
"""

# ╔═╡ edbd2b1c-1452-41a6-962c-3434bd420020
md"""
## Células auxiliares (não altere estas células)
"""

# ╔═╡ d9672a6f-97af-43d1-9a30-50495204fec8
 TableOfContents()

# ╔═╡ 0b4adabb-93f9-40d0-8571-b651dd68535c
NotaFinal = I + II + III + IV + V 

# ╔═╡ c7190cc0-08d8-45c8-b5de-e5630e0ff00e
html"""<style>
main {
    max-width: 900px;
    align-self: flex-start;
    margin-left: 100px;
}
"""

# ╔═╡ 1bf47443-0ee4-482a-b637-8081620c144b
begin
	π_ZL3= -r̄3 / (1+λ3)
	πd_min3 = - Ā3 / ϕ3
	Y_ZL3 = Ā3 * m3 - (m3 *  ϕ3 * r̄3) / (1+λ3)
	ρ4 = -3.15
end;

# ╔═╡ fc4af909-b4c5-4ebd-9e4b-fc93e3d31b8f
begin
	Y3_ZL = 13 : 0.0001 : Y_ZL3

	πd3_normal = πd_max3 .- (1 ./(m3 .* ϕ3 .* λ3)) .* Y3_ZL
	
	πd3_ZL = πd_min3 .+ (1 ./(m3 .* ϕ3)) .* Y3_ZL

	πs4 = πs_min3 .+ γ3 .*Y3 .+ ρ4

	trace10_24 = scatter(; x = Y3_ZL , y = πd3_normal , mode = "line", name ="AD", line_color = "Blue")
	
	trace10_25 = scatter(; x = Y3_ZL , y = πd3_ZL , mode = "line", name ="ADzl", line_color = "BlueViolet")

	trace10_26 = scatter(; x = [13, 16] , y = [π_ZL3 , π_ZL3] , line_dash="dashdot", 
		line_width = "0.5", name = "ZLB", line_color = "black")

	trace10_27 = scatter(;x = Y3, y = πs4, mode="lines", line_color ="Red",line_width = "3", name="AS")

	trace10_28 = scatter(; x = [15.2], y = [0.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))

	trace10_29 = scatter(; x = [15.466777], y = [-1.3333333], text =["2"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Red", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))

	trace10_30 = scatter(; x = [14.8], y = [-3], text =["3"], 
					textposition = "top center", name ="Eq3", mode="markers+text", marker_size= "12",
					marker_color="Gray", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))


		
	layout10_26 = Layout(
					title_text = "The AD/AS with a ZLB_4",
					title_x = 0.5,
					hovermode = "x",
					xaxis_title = "GDP trillion dollars (Y)",
					xaxis_range = [14.4 , 15.6],
					#yaxis_range=[-6 ,8],
					yaxis_title = "Rate of inflation (π)",
					yaxis_range=[-4 ,4], 
					)

	p10_27 = Plot([trace9_0, trace10_24, trace10_25, trace10_26, trace10_27, trace10_28, trace10_29, trace10_30], layout10_26)
	
end

# ╔═╡ 8892c48d-5647-4ecf-9edb-51370332d171
begin
	t = 500 # number of iterations we want to simulate
	n = length(d_1) # telling the routine how many initial conditions are in the loop
	d = [d_1  zeros(n, t-1)] # preallocation to increase performance

	 	for i = 1 : t-1 # the "for" loop
	     	d[i+1] = p + ((1+r)/(1+g))*d[i] 
	 	end
end

# ╔═╡ 095691a9-2b67-439e-a19f-61312496b3b5
begin
layout10_91 = Layout(;
		
		title_text = "The evolution of Public Debt as % of GDP", 
		title_x =0.5,
		
		hovermode="x",
		
		
        xaxis = attr(
               title = "Years", 
               #tickformat = "%Y",
               #hoverformat = "%Y-M%m",
               #tick0 = "1997/10/01",
               ),
		
        #xaxis_range = [2000, 2020],
        yaxis_title = "Debt / GDP",
        #yaxis_range=[-2, 2], 
        titlefont_size = 16)
Plot(d', mode = "lines", line_width = "2.5", layout10_91)
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"

[compat]
HypertextLiteral = "~0.9.3"
NLsolve = "~4.5.1"
PlotlyBase = "~0.8.18"
PlutoUI = "~0.7.28"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.8.0"
manifest_format = "2.0"
project_hash = "c394fae5ae44015faf1cb5773505292afb14817e"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "8eaf9f1b4921132a4cff3f36a1d9ba923b14a481"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.1.4"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Compat", "IfElse", "LinearAlgebra", "Requires", "SparseArrays", "Static"]
git-tree-sha1 = "1ee88c4c76caa995a885dc2f22a5d548dfbbc0ba"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "3.2.2"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.ChainRulesCore]]
deps = ["Compat", "LinearAlgebra", "SparseArrays"]
git-tree-sha1 = "926870acb6cbcf029396f2f2de030282b6bc1941"
uuid = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
version = "1.11.4"

[[deps.ChangesOfVariables]]
deps = ["ChainRulesCore", "LinearAlgebra", "Test"]
git-tree-sha1 = "bf98fa45a0a4cee295de98d4c1462be26345b9a1"
uuid = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
version = "0.1.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "Colors", "FixedPointNumbers", "Random"]
git-tree-sha1 = "a851fec56cb73cfdf43762999ec72eff5b86882a"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.15.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "024fe24d83e4a5bf5fc80501a314ce0d1aa35597"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.0"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "417b0ed7b8b838aa6ca0a87aadf1bb9eb111ce40"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.8"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.Compat]]
deps = ["Base64", "Dates", "DelimitedFiles", "Distributed", "InteractiveUtils", "LibGit2", "Libdl", "LinearAlgebra", "Markdown", "Mmap", "Pkg", "Printf", "REPL", "Random", "SHA", "Serialization", "SharedArrays", "Sockets", "SparseArrays", "Statistics", "Test", "UUIDs", "Unicode"]
git-tree-sha1 = "44c37b4636bc54afac5c574d2d02b625349d6582"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "3.41.0"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "0.5.2+0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"

[[deps.DiffResults]]
deps = ["StaticArrays"]
git-tree-sha1 = "c18e98cba888c6c25d1c3b048e4b3380ca956805"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.0.3"

[[deps.DiffRules]]
deps = ["LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "9bc5dac3c8b6706b58ad5ce24cffd9861f07c94f"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.9.0"

[[deps.Distances]]
deps = ["LinearAlgebra", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "3258d0659f812acde79e8a74b11f17ac06d0ca04"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.7"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "b19534d1895d702889b219c382a6e18010797f0b"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.8.6"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "SparseArrays", "StaticArrays"]
git-tree-sha1 = "8b3c09b56acaf3c0e581c66638b85c8650ee9dca"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.8.1"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions", "StaticArrays"]
git-tree-sha1 = "2b72a5624e289ee18256111657663721d59c143e"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.24"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
git-tree-sha1 = "2b078b5a615c6c0396c77810d92ee8c6f470d238"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.3"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "f7be53659ab06ddc986428d3a9dcc95f6fa6705a"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.2"

[[deps.IfElse]]
git-tree-sha1 = "debdd00ffef04665ccbb3e150747a77560e8fad1"
uuid = "615f187c-cbe4-4ef1-ba3b-2fcf58d6d173"
version = "0.1.1"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InverseFunctions]]
deps = ["Test"]
git-tree-sha1 = "a7254c0acd8e62f1ac75ad24d5db43f5f19f3c65"
uuid = "3587e190-3f89-42d0-90ee-14403ec27112"
version = "0.1.2"

[[deps.IrrationalConstants]]
git-tree-sha1 = "7fd44fd4ff43fc60815f8e764c0f352b83c49151"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.1.1"

[[deps.JLLWrappers]]
deps = ["Preferences"]
git-tree-sha1 = "642a199af8b68253517b80bd3bfd17eb4e84df6e"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.3.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "8076680b162ada2a031f707ac7b4953e30667a37"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.2"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "f27132e551e959b3667d8c93eae90973225032dd"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.1.1"

[[deps.LinearAlgebra]]
deps = ["Libdl", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["ChainRulesCore", "ChangesOfVariables", "DocStringExtensions", "InverseFunctions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "e5718a00af0ab9756305a0392832c8952c7426c1"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.6"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "3d3e902b31198a27340d0bf00d6ac452866021cf"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.9"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.0+0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.2.1"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "50310f934e55e5ca3912fb941dec199b49ca9b68"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.2"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
git-tree-sha1 = "f755f36b19a5116bb580de457cda0c140153f283"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "0.3.6"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.20+0"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+0"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "85f8e6578bf1f9ee0d11e7bb1b1456435479d47c"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.4.1"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates"]
git-tree-sha1 = "d7fa6237da8004be601e19bd6666083056649918"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.1.3"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.8.0"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "180d744848ba316a3d0fdf4dbd34b77c7242963a"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.18"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "Markdown", "Random", "Reexport", "UUIDs"]
git-tree-sha1 = "d5c20cd458002f6d24cb80ecc6b4533b67ffc33d"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.28"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "2cf929d64681236a2e074ffafb8d568733d2e6af"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.2.3"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "8f82019e525f4d5c669692772a6f4b0a58b06a6a"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.2.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.SharedArrays]]
deps = ["Distributed", "Mmap", "Random", "Serialization"]
uuid = "1a1011a3-84de-559e-8e89-a11a2f7dc383"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SparseArrays]]
deps = ["LinearAlgebra", "Random"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.SpecialFunctions]]
deps = ["ChainRulesCore", "IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "e08890d19787ec25029113e88c34ec20cac1c91e"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.0.0"

[[deps.Static]]
deps = ["IfElse"]
git-tree-sha1 = "7f5a513baec6f122401abfc8e9c074fdac54f6c1"
uuid = "aedffcd0-7271-4cad-89d0-dc628f76c6d3"
version = "0.4.1"

[[deps.StaticArrays]]
deps = ["LinearAlgebra", "Random", "Statistics"]
git-tree-sha1 = "de9e88179b584ba9cf3cc5edbb7a41f26ce42cda"
uuid = "90137ffa-7385-5640-81b9-e52037218182"
version = "1.3.0"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"

[[deps.StatsAPI]]
git-tree-sha1 = "d88665adc9bcf45903013af0982e2fd05ae3d0a6"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.2.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.0"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.12+3"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl", "OpenBLAS_jll"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.1.1+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─0b869e70-3717-11ec-202c-6b94dac7daf3
# ╠═b326715f-c37f-44d2-92f9-6264368a18b2
# ╟─694d78c7-4762-4d40-8f9a-6c3d16916d4e
# ╟─b72215bb-8e3a-46e2-8817-271befe1178c
# ╟─60bab761-8537-46e3-9940-953cd47da4be
# ╟─4109af60-6178-4148-8efe-890245077188
# ╟─25743265-a4d8-45c0-8c17-e75a2858441a
# ╟─e56d9748-1b72-48cf-ab1e-da84807da7c4
# ╟─15f5ca45-b1de-4203-ad0d-bdb45e1f9c10
# ╟─4a5d4ce9-ce74-4dd5-8ef9-4abb333b1d4b
# ╠═c7e2c3fc-bf1c-4b1b-882a-b9e36d66a32b
# ╟─9b0f3199-ff28-4820-bcad-e59bc65ce8a6
# ╟─541d8125-e5d0-46ec-a26d-aa1a130c38b2
# ╟─ae593638-a05c-4255-9681-39a9e10efd16
# ╟─f604c97e-bbbf-42f3-b602-ae183a32acc7
# ╠═cff3fc5b-326b-4efe-836b-229cd23f83cc
# ╟─9b622087-ad34-4f19-9929-cbdf0256eae0
# ╟─7a8ac6a0-09cf-437e-9b8d-277182c0cdd0
# ╠═37e34e48-c2a7-4ffd-ac97-1a6ecb44ea92
# ╠═d3341903-3381-47bf-b6b0-6b909542a032
# ╠═c3ad91a0-45be-468b-8113-395e10902afb
# ╟─f3d1f71c-5108-4394-a98d-dc670f1091ae
# ╟─6db02201-bbe3-4ca8-a36b-7a5ac9e6385e
# ╟─f4efa92e-9a43-4bc3-8924-9ef7adeba5fd
# ╟─b52852c9-8cd0-4070-bcd9-b73c63bb7b83
# ╠═83da306c-64fa-4231-b396-b2006cd3ae05
# ╟─36a0155e-86a5-461a-9b29-bf5b12e29e1b
# ╟─4f2bd28d-abe2-43eb-9b7c-65e4ee574499
# ╟─fc4af909-b4c5-4ebd-9e4b-fc93e3d31b8f
# ╟─bfd9b931-74b2-4f61-867c-cdba8df08d4e
# ╠═1abf1b21-a268-45da-bcfc-b9cab7119ef4
# ╟─52c76dc2-146c-4178-9aa3-d132a0551168
# ╟─40de1d39-effa-460b-8ccd-85d5be501a63
# ╟─5ec7390c-2383-4033-9089-1c051b806912
# ╟─095691a9-2b67-439e-a19f-61312496b3b5
# ╟─f70f963d-1d2b-4db7-bf4c-4175ad1c3df8
# ╠═bc7a7a3d-b43a-4db1-9f42-212226e10a29
# ╟─f2956bed-9534-4c57-bfaa-fbef3c4af810
# ╟─edbd2b1c-1452-41a6-962c-3434bd420020
# ╠═d9672a6f-97af-43d1-9a30-50495204fec8
# ╠═0b4adabb-93f9-40d0-8571-b651dd68535c
# ╟─c7190cc0-08d8-45c8-b5de-e5630e0ff00e
# ╟─1bf47443-0ee4-482a-b637-8081620c144b
# ╟─8892c48d-5647-4ecf-9edb-51370332d171
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
